
/* Exit statuses */

#define SUCCESS 0
#define OPENERROR 1
#define EIOERROR 2
#define INFO 3
#define LIMITEXCEEDED 4
#define BADOPTION 5
#define BADOPTIONARG 6
#define OUTOFMEMORY 7
#define BADRECORD 8
#define OTHERERROR 9
#define RANGEERROR 10
#define NOTSORTED 11
#define BADENCODING 12
